==> scribus_0.6.orig.tar.gz: scribus-0.6/scribus/spalette.h <==
/***************************************************************************
                          spalette.h  -  description
                             -------------------
    begin                : Wed Apr 25 2001
    copyright            : (C) 2001 by Franz Schmid
    email                : Franz.Schmid@altmuehlnet.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPALETTE_H
#define SPALETTE_H

#include <qdialog.h>
#include <qlistbox.h>
#include <qlayout.h>
#include "scribusdoc.h"

/**
  *@author Franz Schmid
  */

class Spalette : public QDialog  {
Q_OBJECT
public: 
	Spalette(QWidget* parent);
	~Spalette();
  void closeEvent(QCloseEvent *ce);
	
	QListBox *ListBox1;
	ScribusDoc *doc;
	
public slots:
	void SetFormats(ScribusDoc *dd);
	void updateFList();
	void selFormat(QListBoxItem *c);

protected:
    QHBoxLayout* Form1Layout;
	
signals:
	void Schliessen();
	void NewStyle(int);
	void EditSt();
};

#endif

==> scribus-0.8.tar.gz: scribus-0.8/scribus/spalette.h <==
/***************************************************************************
                          spalette.h  -  description
                             -------------------
    begin                : Wed Apr 25 2001
    copyright            : (C) 2001 by Franz Schmid
    email                : Franz.Schmid@altmuehlnet.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPALETTE_H
#define SPALETTE_H

#include <qdockwindow.h>
#include <qlistbox.h>
#include <qlayout.h>
#include "scribusdoc.h"

/**
  *@author Franz Schmid
  */

class Spalette : public QDockWindow  {
Q_OBJECT
public: 
	Spalette(QWidget* parent);
	~Spalette();
	
	QListBox *ListBox1;
	ScribusDoc *doc;
	bool Sichtbar;
	
public slots:
	void SetFormats(ScribusDoc *dd);
	void updateFList();
	void selFormat(QListBoxItem *c);
	void Verbergen(bool vis);
	
signals:
	void Schliessen();
	void NewStyle(int);
	void EditSt();
};

#endif
